# Generated by Django 3.2.10 on 2021-12-30 01:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('alumni', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='corporationalliancehistory',
            name='alliance_id',
            field=models.PositiveIntegerField(blank=True, db_index=True, null=True),
        ),
        migrations.AlterField(
            model_name='corporationalliancehistory',
            name='corporation_id',
            field=models.PositiveIntegerField(db_index=True),
        ),
    ]
